Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon DynamoDB Accelerator (DAX).

Actions, resources, and condition keys for Amazon DynamoDB Accelerator (DAX) - Service Authorization Reference

# Actions, resources, and condition keys for Amazon DynamoDB Accelerator (DAX)

Amazon DynamoDB Accelerator (DAX) (service prefix: `dax` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon DynamoDB Accelerator (DAX)
- Resource types defined by Amazon DynamoDB Accelerator (DAX)
- Condition keys for Amazon DynamoDB Accelerator (DAX)

## Actions defined by Amazon DynamoDB Accelerator (DAX)

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
BatchGetItem | Grants permission to return the attributes of one or more items from one or more tables | Read | application* |  |
BatchWriteItem | Grants permission to put or delete multiple items in one or more tables | Write | application* |  |
ConditionCheckItem | Grants permission to the ConditionCheckItem operation that checks the existence of a set of attributes for the item with the given primary key | Read | application* |  |
CreateCluster | Grants permission to create a DAX cluster | Write | application* |  | dax:CreateParameterGroup dax:CreateSubnetGroup ec2:CreateNetworkInterface ec2:DeleteNetworkInterface ec2:DescribeNetworkInterfaces ec2:DescribeSecurityGroups ec2:DescribeSubnets ec2:DescribeVpcs iam:GetRole iam:PassRole
CreateParameterGroup | Grants permission to create a parameter group | Write |  |  |
CreateSubnetGroup | Grants permission to create a subnet group | Write |  |  |
DecreaseReplicationFactor | Grants permission to remove one or more nodes from a DAX cluster | Write | application* |  |
DeleteCluster | Grants permission to delete a previously provisioned DAX cluster | Write | application* |  |
DeleteItem | Grants permission to delete a single item in a table by primary key | Write | application* |  |
| dax:EnclosingOperation |
DeleteParameterGroup | Grants permission to delete the specified parameter group | Write |  |  |
DeleteSubnetGroup | Grants permission to delete a subnet group | Write |  |  |
DescribeClusters | Grants permission to return information about all provisioned DAX clusters | List | application |  |
DescribeDefaultParameters | Grants permission to return the default system parameter information for DAX | List |  |  |
DescribeEvents | Grants permission to return events related to DAX clusters and parameter groups | List |  |  |
DescribeParameterGroups | Grants permission to return a list of parameter group descriptions | List |  |  |
DescribeParameters | Grants permission to return the detailed parameter list for a particular parameter group | Read |  |  |
DescribeSubnetGroups | Grants permission to return a list of subnet group descriptions | List |  |  |
GetItem | Grants permission to the GetItem operation that returns a set of attributes for the item with the given primary key | Read | application* |  |
| dax:EnclosingOperation |
IncreaseReplicationFactor | Grants permission to add one or more nodes to a DAX cluster | Write | application* |  |
ListTags | Grants permission to return a list all of the tags for a DAX cluster | Read | application* |  |
PutItem | Grants permission to create a new item, or replace an old item with a new item | Write | application* |  |
| dax:EnclosingOperation |
Query | Grants permission to use the primary key of a table or a secondary index to directly access items from that table or index | Read | application* |  |
RebootNode | Grants permission to reboot a single node of a DAX cluster | Write | application* |  |
Scan | Grants permission to return one or more items and item attributes by accessing every item in a table or a secondary index | Read | application* |  |
TagResource | Grants permission to associate a set of tags with a DAX resource | Tagging | application* |  |
UntagResource | Grants permission to remove the association of tags from a DAX resource | Tagging | application* |  |
UpdateCluster | Grants permission to modify the settings for a DAX cluster | Write | application* |  |
UpdateItem | Grants permission to edit an existing item's attributes, or adds a new item to the table if it does not already exist | Write | application* |  |
| dax:EnclosingOperation |
UpdateParameterGroup | Grants permission to modify the parameters of a parameter group | Write |  |  |
UpdateSubnetGroup | Grants permission to modify an existing subnet group | Write |  |  |

## Resource types defined by Amazon DynamoDB Accelerator (DAX)

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
application | `arn:$ { Partition}:dax:$ { Region}:$ { Account}:cache/$ { ClusterName}` |

## Condition keys for Amazon DynamoDB Accelerator (DAX)

Amazon DynamoDB Accelerator (DAX) defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
dax:EnclosingOperation | Used to block Transactions APIs calls and allow the non-Transaction APIs calls and vice-versa | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.